package eu.kanade.tachiyomi.ui.security

import android.os.Bundle
import androidx.appcompat.app.AppCompatActivity
import androidx.biometric.BiometricPrompt
import eu.kanade.tachiyomi.R
import eu.kanade.tachiyomi.data.preference.PreferencesHelper
import java.util.Date
import java.util.concurrent.Executors
import uy.kohesive.injekt.injectLazy

/**
 * Blank activity with a BiometricPrompt.
 */
class BiometricUnlockActivity : AppCompatActivity() {

    private val preferences: PreferencesHelper by injectLazy()
    private val executor = Executors.newSingleThreadExecutor()

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        val biometricPrompt = BiometricPrompt(this, executor, object : BiometricPrompt.AuthenticationCallback() {
            override fun onAuthenticationError(errorCode: Int, errString: CharSequence) {
                super.onAuthenticationError(errorCode, errString)
                finishAffinity()
            }

            override fun onAuthenticationSucceeded(result: BiometricPrompt.AuthenticationResult) {
                super.onAuthenticationSucceeded(result)
                SecureActivityDelegate.locked = false
                preferences.lastAppUnlock().set(Date().time)
                finish()
            }
        })

        val promptInfo = BiometricPrompt.PromptInfo.Builder()
                .setTitle(getString(R.string.unlock_library))
                .setDeviceCredentialAllowed(true)
                .build()

        biometricPrompt.authenticate(promptInfo)
    }
}
